
# Type: is_class_field


indicates that any instance, i,  the domain of this slot will include an assert of i s range

URI: [meta:is_class_field](https://w3id.org/biolink/biolinkml/meta/is_class_field)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
